# Discount

Every coupon is loaded with a discount. The discount might be in currency (only value) or percentage (value and percentage).

![Discount](https://github.com/Wolfterro/django-simple-coupons/raw/master/docs/images/discount-create.png)